package com.xylink.config;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.xylink.model.AppToken;
import com.xylink.util.HttpUtil;
import com.xylink.util.Result;
import com.xylink.util.SchedulerUtil;
import com.xylink.util.SslUtils;
import org.apache.commons.lang3.StringUtils;

import java.io.*;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * Created by wenya on 17/9/11.
 */
public class SDKConfigMgr{

    private static final String CONFIG_FILE = "/com/xylink/config/config.json";

    private static String DEFAULT_SERVER_HOST = "https://sdk.xylink.com";

    private static SDKConfig sdkConfig;

    private static final ObjectMapper objectMapper = new ObjectMapper();

    static {
        sdkConfig = loadConfigs();
        if(sdkConfig == null) {
            sdkConfig = new SDKConfig();
            sdkConfig.setServerHost(DEFAULT_SERVER_HOST);
        }
    }

    public static String getServerHost() {
        return sdkConfig.getServerHost();
    }

    public static String getXyClientid() {
        return sdkConfig.getXyClientid();
    }

    public static String getAccessToken() {
        return sdkConfig.getAccessToken();
    }

    public static void setServerHost(String host) {
        if(host == null || host.trim().isEmpty()) {
            throw new IllegalArgumentException("host cannot be empty.");
        }
        if(!DEFAULT_SERVER_HOST.equals(host.toLowerCase().trim())) {
            try {
                SslUtils.ignoreSsl();
            } catch (Exception e) {
                throw new IllegalArgumentException("Failed to ignore ssl cert.", e);
            }
        }
        sdkConfig.setServerHost(host);
    }

    public static void setXyAppInfo(String xyClientid,String client_secret,String enterpriseId){
        if(StringUtils.isBlank(xyClientid) || StringUtils.isBlank(client_secret) || StringUtils.isBlank(enterpriseId)) {
            throw new IllegalArgumentException("appInfo cannot be empty.");
        }
        sdkConfig.setXyClientid(xyClientid);
        sdkConfig.setEnterpriseId(enterpriseId);
        sdkConfig.setXyClientSecret(client_secret);
        System.out.println("scheduler refesh client init delay "+sdkConfig.getClientRefreshCycle());
        initAccesstoken(sdkConfig);
        SchedulerUtil.scheduleAtFixedRate(new Runnable() {
            @Override
            public void run() {
                refreshToken();
            }
        }, sdkConfig.getClientRefreshCycle(), sdkConfig.getClientRefreshCycle(), TimeUnit.HOURS);
    }

    public static void setClientRefreshCycle(int clientRefreshCycle) {
        sdkConfig.setClientRefreshCycle(clientRefreshCycle);
    }

    private static SDKConfig loadConfigs() {
        try {
            InputStream inputStream = SDKConfigMgr.class.getResourceAsStream(CONFIG_FILE);
            SDKConfig sdkConfig = objectMapper.readValue(inputStream, SDKConfig.class);
            return sdkConfig;
        } catch (IOException e) {
            return new SDKConfig();
        }
    }

    private static void initAccesstoken(SDKConfig sdkConfig){
        try{
            if (null!=sdkConfig &&
                    StringUtils.isNotBlank(sdkConfig.getXyClientid()) &&
                    StringUtils.isNotBlank(sdkConfig.getXyClientSecret()) &&
                    StringUtils.isNotBlank(sdkConfig.getEnterpriseId())){
                AppToken appToken = new AppToken();
                appToken.setClient_id(sdkConfig.getXyClientid());
                appToken.setClient_secret(sdkConfig.getXyClientSecret());
                appToken.setEnterpriseId(sdkConfig.getEnterpriseId());
                String jsonEntity = new ObjectMapper().writeValueAsString(appToken);
                Result result = HttpUtil.getResponse(sdkConfig.getServerHost()+"/admin/login/oauth/app_token","POST",jsonEntity, Map.class);
                if (result.isSuccess()){
                    Map appTokenMap = (Map)result.getData();
                    if (appTokenMap.get("message").equals("success")){
                        sdkConfig.setAccessToken((String) ((Map)appTokenMap.get("data")).get("access_token"));
                        sdkConfig.setRefreshToken((String) ((Map)appTokenMap.get("data")).get("refresh_token"));
                    }
                }
            }
        }catch(Exception e){
            System.out.println("initAccesstoken error"+e.getMessage());
        }
    }

    private static void refreshToken(){
        if (null!=sdkConfig && StringUtils.isNotBlank(sdkConfig.getRefreshToken())){
            AppToken appToken = new AppToken();
            appToken.setRefresh_token(sdkConfig.getRefreshToken());
            try{
                String jsonEntity = new ObjectMapper().writeValueAsString(appToken);
                Result result = HttpUtil.getResponse(sdkConfig.getServerHost()+"/admin/login/refresh_token","POST",jsonEntity, Map.class);
                if (result.isSuccess()){
                    System.out.println(appToken.getRefresh_token() + "refreshToken");
                    Map appTokenMap = (Map)result.getData();
                    if (appTokenMap.get("message").equals("success")){
                        sdkConfig.setAccessToken((String) ((Map)appTokenMap.get("data")).get("access_token"));
                        sdkConfig.setRefreshToken((String) ((Map)appTokenMap.get("data")).get("refresh_token"));
                    }
                }
            }catch(Exception e){
                System.out.println("refreshToken error"+e.getMessage());
            }
        }
    }
}
