package com.xylink.util;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.xylink.config.SDKConfigMgr;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;

import java.io.*;
import java.net.HttpURLConnection;
import java.net.InetSocketAddress;
import java.net.Proxy;
import java.net.URL;
import java.util.HashMap;

/**
 * Created by maolizhi on 12/13/2016.
 */
public class HttpUtil {

    private static String proxyHost;
    private static int proxyPort;

    public static Result getResponse(String surl,String method,String jsonEntity,Class<?>clazz) throws IOException {
        HttpURLConnection conn = HttpUtil.getHttpURLConnection(jsonEntity,surl,method);
        InputStream is = null;
        int status = conn.getResponseCode();
        if(status == 200 || status == 204) {
            is = conn.getInputStream();
        }else{
            is = conn.getErrorStream();
        }
        String respData = HttpUtil.getResponseData(is);
        conn.disconnect();
        return getResult(status, respData,  clazz);
    }

    public static Result getByteStreamResponse(String surl,String method,String jsonEntity) throws IOException {
        HttpURLConnection conn = HttpUtil.getHttpURLConnection(jsonEntity,surl,method);
        InputStream is = null;
        int status = conn.getResponseCode();
        if(status == 200 || status == 204) {
            is = conn.getInputStream();
        }else{
            is = conn.getErrorStream();
        }
        byte[] bytes = HttpUtil.getStreamResponse(is);
        conn.disconnect();
        return getByteResult(status, bytes);
    }

    /**
     * convert byte array to image or video
     * @param bytes
     * @param path
     */
    public static void convertByteArrayToImageOrVideo(byte[] bytes,String path){
        FileOutputStream fos = null;
        try {
            fos = new FileOutputStream(path);
            fos.write(bytes);
        } catch (FileNotFoundException e) {
            System.out.println("File Path not found!");
        } catch (IOException e) {
            System.out.println("Convert byte array to image,IO Errot!");
        }

    }


    private static  HttpURLConnection getHttpURLConnection(String jsonEntity,String surl, String method) throws IOException {
        if (StringUtils.isNotBlank(SDKConfigMgr.getXyClientid())&&StringUtils.isNotBlank(SDKConfigMgr.getAccessToken())){
            surl = surl.replace("/v1/","/v3/");
        }
        URL url = new URL(surl);
        HttpURLConnection conn = null;
        if(StringUtils.isNotBlank(proxyHost)){
            System.out.println("use proxy");
            Proxy proxy = new Proxy(Proxy.Type.HTTP, new InetSocketAddress(proxyHost, proxyPort));
            conn = (HttpURLConnection) url.openConnection(proxy);
        }else {
            conn = (HttpURLConnection) url.openConnection();
        }
        if (StringUtils.isNotBlank(SDKConfigMgr.getXyClientid())&&StringUtils.isNotBlank(SDKConfigMgr.getAccessToken())){
            HashMap globalParams = new HashMap<String, String>();
            globalParams.put(SignUtil.SIGN_CLIENT_ID_KEY_NEW, SDKConfigMgr.getXyClientid());
            globalParams.put(SignUtil.SIGN_SIGN_TYPE_KEY_NEW, SignUtil.SignType.SHA256.name());
            String timeStamp = String.valueOf(System.currentTimeMillis());
            globalParams.put(SignUtil.SIGN_TIMESTAMP_KEY_NEW,timeStamp);
            String nonce = DigestUtils.sha256Hex(timeStamp+SignUtil.randomAlphanumeric(16));
            globalParams.put(SignUtil.SIGN_NONCE_KEY_NEW,nonce);
            String sign = SignUtil.getSign(method,globalParams,surl,jsonEntity,SDKConfigMgr.getAccessToken());
            conn.addRequestProperty("Accept", "application/json");
            conn.addRequestProperty(SignUtil.SIGN_CLIENT_ID_KEY_NEW, SDKConfigMgr.getXyClientid());
            conn.addRequestProperty(SignUtil.SIGN_SIGN_TYPE_KEY_NEW, SignUtil.SignType.SHA256.name());
            conn.addRequestProperty(SignUtil.SIGN_TIMESTAMP_KEY_NEW,timeStamp);
            conn.addRequestProperty(SignUtil.SIGN_NONCE_KEY_NEW,nonce);
            conn.addRequestProperty(SignUtil.SIGN_SIGN_KEY_NEW, sign);
            conn.addRequestProperty(SignUtil.Authorization, "Bearer "+SDKConfigMgr.getAccessToken());
        }
        conn.setRequestMethod(method);
        conn.addRequestProperty("Accept", "application/json");
        conn.addRequestProperty("Accept-Charset", "UTF-8");
        conn.addRequestProperty("Content-Type", "application/json;charset=utf-8");
        conn.setDoOutput(true);
        conn.setDoInput(true);
        if(jsonEntity != null && !"".equals(jsonEntity.trim())) {
            conn.getOutputStream().write(jsonEntity.getBytes("utf-8"));
        }
        conn.connect();
        return conn;
    }

    private static String getResponseData(InputStream is) throws IOException {
        if(is != null) {
            Reader reader = new InputStreamReader(is, "UTF-8");
            StringBuilder response = new StringBuilder();
            char[] buff = new char[2048];
            for (int n; (n = reader.read(buff)) != -1; ) {
                response.append(buff, 0, n);
            }
            return response.toString();
        }else{
            return "";
        }

    }


    private static Result getResult(int status, String respData, Class<?> clazz ) {
        ObjectMapper objectMapper = new ObjectMapper();
        int responseCode = 200;
        RestMessage restMessage = null;
        Result result = new Result();
        if(status == 200 || status == 204) {
            try {
                result.setSuccess(true);
                if(clazz != null) {
                    if(!clazz.getName().equals(String.class.getName())) {
                        if(respData != null && !"".equals(respData.trim()))
                        result.setData(objectMapper.readValue(respData, clazz));
                    }else{
                        result.setData(respData);
                    }
                }
                result.setErrorStatus(responseCode);
            } catch (Exception e) {
                System.out.println("JSon String convert to Object error!");
                e.printStackTrace();
            }
        }else{
            result.setErrorStatus(status);
            result.setSuccess(false);
            try {
                restMessage = objectMapper.readValue(respData, RestMessage.class);
                responseCode = restMessage.getErrorCode();
                result.setData(restMessage);
                result.setErrorStatus(responseCode);// 有详细错误码，使用详细的错误码
                result.setErrorMsg(restMessage.getUserMessage());
            }catch(Exception e){
                System.out.println("JSon String convert to RestMessage error!");
            }
        }

        return result;
    }




    private static byte[] getStreamResponse(InputStream is) throws IOException {
        if(is != null) {
            ByteArrayOutputStream swapStream = new ByteArrayOutputStream();
            byte[] buff = new byte[1024]; //buff用于存放循环读取的临时数据
            int rc = 0;
            while ((rc = is.read(buff, 0, 100)) > 0) {
                swapStream.write(buff, 0, rc);
            }
            byte[] bytes = swapStream.toByteArray(); //bytes为转换之后的结果
            return bytes;
        }
        return null;

    }

    private static Result getByteResult( int status, byte[] bytes) {
        ObjectMapper objectMapper = new ObjectMapper();
        int responseCode = 200;
        RestMessage restMessage = null;
        Result result = new Result();
        if(status == 200 || status == 204) {
            result.setSuccess(true);
            result.setData(bytes);
            result.setErrorStatus(200);

        }else{
            try {
                String respData = new String(bytes);
                restMessage = objectMapper.readValue(respData, RestMessage.class);
                responseCode = restMessage.getErrorCode();
                result.setSuccess(false);
                result.setData(restMessage);
                result.setErrorStatus(responseCode);
            }catch(Exception e){
                System.out.println("JSon String convert to RestMessage error!");
            }
        }

        return result;
    }

    public static void setProxy(String host,int port) {
        proxyHost = host;
        proxyPort = port;
    }

}
