package com.xylink.util;

import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;

import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.Charset;
import java.util.*;

/**
 * Created with IntelliJ IDEA.
 * Description:
 * User: gzm
 * Date: 2020-12-22
 */
public class SignUtil {

    public static void main(String[] args) {
        //参数签名算法测试例子
        String access_token = "919f8b3a-55b0-41d8-a7e5-78efac16bbed";
        HashMap globalParams = new HashMap<String, String>();
        globalParams.put(SIGN_CLIENT_ID_KEY_NEW, "CnOq4cPDt83b3xORztFZOcJl");
        globalParams.put(SIGN_SIGN_TYPE_KEY_NEW, SignType.SHA256.name());
        String timeStamp = String.valueOf(System.currentTimeMillis());
        globalParams.put(SIGN_TIMESTAMP_KEY_NEW, timeStamp);
        String nonce = DigestUtils.sha256Hex(timeStamp+randomAlphanumeric(16));
        globalParams.put(SIGN_NONCE_KEY_NEW,nonce);
        String method = "POST";
        String uri = "https://testdevsdk.xylink.com/api/rest/external/v3/create_meeting?enterpriseId=40260e9046bae2da238ac0b0c572326b91726a83";
        String requestBody = "{\n" +
                "    \"meetingName\": \"my first cloudRoom\"\n" +
                "}";
        String sign = getSign(method,globalParams,uri,requestBody,access_token);
        System.out.println("签名结果:" + sign);
        globalParams.put(SIGN_SIGN_KEY_NEW, sign);
        globalParams.put(Authorization, "Bearer "+access_token);
        System.out.println("======================sign globalParams=============================");
        for(Object param:globalParams.keySet()){
            System.out.println(param+":"+globalParams.get(param));
        }
        System.out.println("======================sign globalParams=============================");
    }

    public static String randomAlphanumeric(int count) {
        return random(count, 0, 0, true, true,null, new Random());
    }

    /**
     * 得到签名
     *
     * @param method     http method
     * @param globalParams     指定的全局参数
     * @param uri     必须包含 eg http://localhost:8888/page/api/rest/v2/handup?aaa=myurltest /page/api/rest/v2/handup?aaa=myurltest
     * @param requestBody  请求体
     * @param access_token  access_token
     * @return
     */
    public static String getSign(String method, Map<String,String> globalParams, String uri, String requestBody, String access_token) {
        requestBody = StringUtils.isBlank(requestBody)?"":requestBody;
        byte[] requestBodyBytes = requestBody.getBytes(Charset.forName("UTF-8"));
        if (uri.startsWith("http")){
            uri = uri.replaceAll("(https|http)://.+/api","/api");
        }
        if (uri.startsWith("wss://")||uri.startsWith("ws://")){
            uri = uri.replaceAll("(wss|ws)://.+/external","/external");
        }
        if (globalParams == null) {
            return "";
        }
        System.out.println("======================sign globalParams=============================");
        for(Object param:globalParams.keySet()){
            System.out.println(param+":"+globalParams.get(param));
        }
        System.out.println("======================sign globalParams=============================");
        StringBuilder sb = new StringBuilder();
        //1.添加method
        sb.append(method).append("\n");
        //header排序
        Set<String> keySet = globalParams.keySet();
        String[] keyArray = keySet.toArray(new String[keySet.size()]);
        Arrays.sort(keyArray);
        //2.添加Headers
        for (String k : keyArray) {
            if (k.equals(SIGN_SIGN_KEY_NEW)||k.contains(Authorization)) {
                continue;
            }
            Object param = globalParams.get(k);
            String paramStr = String.valueOf(param);
            if (paramStr.trim().length() > 0) {
                // 参数值为空，则不参与签名
                sb.append(k).append("=").append(paramStr.trim()).append("&");
            }
        }
        sb = sb.deleteCharAt(sb.length()-1);//去除最后一个&
        sb.append("\n");
        //3.添加uri
        sb.append(uri);
        //4.添加请求的body
        sb.append("\n");
        if(requestBodyBytes != null && requestBodyBytes.length > 0) {
            sb.append(DigestUtils.md5Hex(requestBodyBytes));
        }else{
            sb.append(DigestUtils.md5Hex("".getBytes(Charset.forName("UTF-8"))));
        }
        //5.添加token
        sb.append("\n");
        sb.append(ACCESS_TOKEN+"=").append(access_token);
        System.out.println("======================sign string=============================");
        System.out.println(sb.toString());
        System.out.println("======================sign string=============================");
        String signStr = "";
        //加密
        SignType type = null;
        String signType = globalParams.get(SIGN_SIGN_TYPE_KEY_NEW);
        if (signType != null && signType.length() > 0) {
            type = SignType.valueOf(signType);
        }
        if (type == null) {
            type = SignType.MD5;
        }
        switch (type) {
            case MD5:
                signStr = DigestUtils.md5Hex(sb.toString()).toUpperCase();
                break;
            case SHA256:
                signStr = DigestUtils.sha256Hex(sb.toString()).toUpperCase();
                break;
            case HMAC_SHA256:
                signStr = sha256HMAC(sb.toString(),access_token).toUpperCase();
            default:
                break;
        }
        System.out.println("sign result "+signStr);
        return signStr;
    }

    public enum SignType {
        MD5,
        SHA256,
        HMAC_SHA256;

        public static boolean contains(String type) {
            for (SignType typeEnum : SignType.values()) {
                if (typeEnum.name().equals(type)) {
                    return true;
                }
            }
            return false;
        }
    }
    /**
     * sha256_HMAC加密
     * @param message 消息
     * @param secret  秘钥
     * @return 加密后字符串
     */
    public static String sha256HMAC(String message, String secret) {
        String hash = "";
        try {
            Mac sha256_HMAC = Mac.getInstance("HmacSHA256");
            SecretKeySpec secret_key = new SecretKeySpec(secret.getBytes("UTF-8"), "HmacSHA256");
            sha256_HMAC.init(secret_key);
            byte[] bytes = sha256_HMAC.doFinal(message.getBytes("UTF-8"));
            hash = byteArrayToHexString(bytes);
        } catch (Exception e) {
        }
        return hash;
    }

    /**
     * 将加密后的字节数组转换成字符串
     *
     * @param b 字节数组
     * @return 字符串
     */
    public  static String byteArrayToHexString(byte[] b) {
        StringBuilder hs = new StringBuilder();
        String stmp;
        for (int n = 0; b!=null && n < b.length; n++) {
            stmp = Integer.toHexString(b[n] & 0XFF);
            if (stmp.length() == 1) {
                hs.append('0');
            }
            hs.append(stmp);
        }
        return hs.toString().toLowerCase();
    }

    /**
     * <p>Creates a random string based on a variety of options, using
     * supplied source of randomness.</p>
     *
     * <p>If start and end are both <code>0</code>, start and end are set
     * to <code>' '</code> and <code>'z'</code>, the ASCII printable
     * characters, will be used, unless letters and numbers are both
     * <code>false</code>, in which case, start and end are set to
     * <code>0</code> and <code>Integer.MAX_VALUE</code>.
     *
     * <p>If set is not <code>null</code>, characters between start and
     * end are chosen.</p>
     *
     * <p>This method accepts a user-supplied {@link Random}
     * instance to use as a source of randomness. By seeding a single
     * {@link Random} instance with a fixed seed and using it for each call,
     * the same random sequence of strings can be generated repeatedly
     * and predictably.</p>
     *
     * @param count  the length of random string to create
     * @param start  the position in set of chars to start at
     * @param end  the position in set of chars to end before
     * @param letters  only allow letters?
     * @param numbers  only allow numbers?
     * @param chars  the set of chars to choose randoms from.
     *  If <code>null</code>, then it will use the set of all chars.
     * @param random  a source of randomness.
     * @return the random string
     * @throws ArrayIndexOutOfBoundsException if there are not
     *  <code>(end - start) + 1</code> characters in the set array.
     * @throws IllegalArgumentException if <code>count</code> &lt; 0.
     * @since 2.0
     */
    public static String random(int count, int start, int end, boolean letters, boolean numbers,
                                char[] chars, Random random) {
        if (count == 0) {
            return "";
        } else if (count < 0) {
            throw new IllegalArgumentException("Requested random string length " + count + " is less than 0.");
        }
        if ((start == 0) && (end == 0)) {
            end = 'z' + 1;
            start = ' ';
            if (!letters && !numbers) {
                start = 0;
                end = Integer.MAX_VALUE;
            }
        }

        char[] buffer = new char[count];
        int gap = end - start;

        while (count-- != 0) {
            char ch;
            if (chars == null) {
                ch = (char) (random.nextInt(gap) + start);
            } else {
                ch = chars[random.nextInt(gap) + start];
            }
            if ((letters && Character.isLetter(ch))
                    || (numbers && Character.isDigit(ch))
                    || (!letters && !numbers))
            {
                if(ch >= 56320 && ch <= 57343) {
                    if(count == 0) {
                        count++;
                    } else {
                        // low surrogate, insert high surrogate after putting it in
                        buffer[count] = ch;
                        count--;
                        buffer[count] = (char) (55296 + random.nextInt(128));
                    }
                } else if(ch >= 55296 && ch <= 56191) {
                    if(count == 0) {
                        count++;
                    } else {
                        // high surrogate, insert low surrogate before putting it in
                        buffer[count] = (char) (56320 + random.nextInt(128));
                        count--;
                        buffer[count] = ch;
                    }
                } else if(ch >= 56192 && ch <= 56319) {
                    // private high surrogate, no effing clue, so skip it
                    count++;
                } else {
                    buffer[count] = ch;
                }
            } else {
                count++;
            }
        }
        return new String(buffer);
    }

    /**四哥n
     * access token
     */
    public static final String ACCESS_TOKEN = "access_token";
    /**
     * 客户端ID KEY，防止通过nginx转发后下划线header有问题，调整header命名
     */
    public static final String SIGN_CLIENT_ID_KEY_NEW = "x-xy-clientid";
    /**
     * 随机字符串 KEY，防止通过nginx转发后下划线header有问题，调整header命名
     */
    public static final String SIGN_NONCE_KEY_NEW = "x-xy-nonce";
    /**
     * 时间戳 KEY，防止通过nginx转发后下划线header有问题，调整header命名
     */
    public static final String SIGN_TIMESTAMP_KEY_NEW = "x-xy-timestamp";
    /**
     * 签名类型 KEY，防止通过nginx转发后下划线header有问题，调整header命名
     */
    public static final String SIGN_SIGN_TYPE_KEY_NEW = "x-xy-signtype";
    /**
     * 签名结果 KEY，防止通过nginx转发后下划线header有问题，调整header命名
     */
    public static final String SIGN_SIGN_KEY_NEW = "x-xy-sign";
    public static final String Authorization = "Authorization";

    private final static long MAX_EXPIRE = 5 * 60 * 1000;
    private final static int MAX_REQUEST_BODY_LENGTH = 200;
}
